<?php

/**
 * Plugin Name: Address Autocomplete For WooCommerce
 * Plugin URI: https://woocommerce.com/products/address-autocomplete-for-woocommerce/
 * Description: Address Autocomplete is a WooCommerce extension integrating Google Maps' location services into the checkout page. When a user selects their location via Google Maps, the relevant address details such as Address, Country, City, State, and Zip Code are automatically populated. This eliminates the need to enter these fields manually, streamlining the checkout process for a smoother, faster experience.
 * Version: 1.2.0
 * Tags: Address Autocomplete, Address autocomplete woocommerce, woocommerce, address, address autocomplete for order form
 * Author: WPExperts
 * Author URI: https://wpexperts.io/
 * Developer: WPExperts
 * Developer URI: https://wpexperts.io/
 * Text Domain: address-autocomplete-for-woocommerce
 * Woo: 6410264:b4a478b9598605a7df2da90f91daa58c
 * WC requires at least: 3.0
 * WC tested up to: 6.6.1
 * Requires Plugins: woocommerce
 * 
 */

namespace Wpexperts\AddressAutocompleteForWoocommerce;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if ( ! defined('SHIPPING_WORKSHOP_VERSION') ) {
	define( 'SHIPPING_WORKSHOP_VERSION', '1.2.0' ); 
}

// Define WC_ADDRESS_AUTOCOMPLETE_URL.
if ( ! defined( 'WC_ADDRESS_AUTOCOMPLETE_URL' ) ) {
	define( 'WC_ADDRESS_AUTOCOMPLETE_URL', plugin_dir_url( __FILE__ ) );
}

// Define WC_ADDRESS_AUTOCOMPLETE_PATH.
if ( ! defined( 'WC_ADDRESS_AUTOCOMPLETE_PATH' ) ) {
	define( 'WC_ADDRESS_AUTOCOMPLETE_PATH', plugin_dir_path( __FILE__ ) );
}

if ( ! defined('WC_ADDRESS_AUTOCOMPLETE_NAME') ) {
	define( 'WC_ADDRESS_AUTOCOMPLETE_NAME', __DIR__ );  
}

if ( file_exists( WC_ADDRESS_AUTOCOMPLETE_PATH . '/vendor/autoload.php' ) ) {
	require_once WC_ADDRESS_AUTOCOMPLETE_PATH . '/vendor/autoload.php';
}

use Wpexperts\AddressAutocompleteForWoocommerce\Admin\GoogleMapApiSetting as GASetting;
use Wpexperts\AddressAutocompleteForWoocommerce\Frontend\WcFrontendHooks as FHooks;

class WC_Address_Autocomplete {

	private static $_instance = null;

	public function __construct() {
		
		/**
		 *  Filter 
		 * 
		 *   @since 1.0
		*/
		$activate = apply_filters( 'address_autocomplete_active_plugins', get_option( 'active_plugins' ) );

		if ( in_array( 'woocommerce/woocommerce.php', $activate ) ) {
			self::init();
			add_action( 'before_woocommerce_init', array( $this, 'woo_hpos_incompatibility' ) );
			add_filter( 'plugin_action_links_' . plugin_basename(__FILE__), array( $this, 'address_autocomplete_action_links' ) );
		} else {
			add_action( 'admin_notices', array( __CLASS__, 'address_autocomplete_admin_notice_error' ) );
		}
		
		/**
		 * Include the dependencies needed to instantiate the block.
		 */
		$aafw_disable_plugin = get_option( 'aafw_allow_manual_address' );
		
		if ('' == $aafw_disable_plugin) {
			add_action('woocommerce_blocks_loaded', function () {

				$google_map_api_key       = get_option( 'google_map_api_key', null );

				if ( null === $google_map_api_key ) {
					return false;
				}

				if ( '' === empty( trim($google_map_api_key) ) ) {
					return false;
				}

				include WC_ADDRESS_AUTOCOMPLETE_PATH . '/shipping-workshop-blocks-integration.php';
				add_action(
					'woocommerce_blocks_checkout_block_registration',
					function ( $integration_registry ) {
						$integration_registry->register( new \Shipping_Workshop_Blocks_Integration() );
					}
				);
			});
		}
	}

	/**
	 * Method Address Autocomplete action_links
	 *
	 * @param array $actions [explicite description]
	 *
	 * @return array
	 */
	public function address_autocomplete_action_links( array $actions ) {
		$deactivate             = $actions['deactivate'];
		
		unset( $actions['deactivate'] );

		$actions['settings']    = sprintf('<a href="%s">%s</a>', admin_url('admin.php?page=map-option'), __('Settings', 'address-autocomplete-for-woocommerce'));
		$actions['deactivate']  = $deactivate;
		
		return $actions;
	}

	/**
	 * Check Is WooCommerce install/active
	 * 
	 * @return
	 */
	public static function address_autocomplete_admin_notice_error() {
		$class = 'notice notice-error';
		$message = esc_html__( 'Address Autocomplete for WooCommerce requires WooCommerce to be install & active.', 'address-autocomplete-for-woocommerce' );
		printf( '<div class="%1$s"><p>%2$s</p></div>', esc_html( $class ), esc_html( $message ) );
	}

	/**
	 * Initalizing the Plugin Files
	 * 
	 */
	public static function init() {
		if ( function_exists( 'load_plugin_textdomain' ) ) {
			load_plugin_textdomain( 'address-autocomplete-for-woocommerce', false, basename( WC_ADDRESS_AUTOCOMPLETE_NAME ) . '/languages/' );
		}

		new GASetting();
		new FHooks();
		add_action( 'admin_enqueue_scripts', array( __CLASS__, 'admin_enqueue_scripts' ) );
		add_action( 'wp_enqueue_scripts', array( __CLASS__, 'front_enqueue_scripts' ) );
	}

	/**
	 * Register style & scripts for Tier Pricing
	 *
	 * @since 1.0
	 */
	public static function admin_enqueue_scripts() {
		$data = isset( $_SERVER['QUERY_STRING'] ) ? sanitize_text_field( wp_unslash( $_SERVER['QUERY_STRING'] ) ) : '';
		parse_str( $data, $query_params );
		if (is_admin() && isset( $query_params['page'] ) && 'map-option' === $query_params['page'] ) {
			wp_register_script( 'wcac-admin-js', WC_ADDRESS_AUTOCOMPLETE_URL . 'assets/Admin/js/admin.js', array( 'jquery' ), SHIPPING_WORKSHOP_VERSION );
			wp_enqueue_script('wcac-admin-js', WC_ADDRESS_AUTOCOMPLETE_URL . 'assets/Admin/js/admin.js', array( 'jquery' ), SHIPPING_WORKSHOP_VERSION, true); // Set the last parameter to true to load the script in the footer

			wp_localize_script('wcac-admin-js', 'mapStyles', array(
				'1' => array( 'label' => __('Standard Map', 'address-autocomplete-for-woocommerce'), 'image' => '1.png' ),
				'2' => array( 'label' => __('Silver Map', 'address-autocomplete-for-woocommerce'), 'image' => '2.png' ),
				'3' => array( 'label' => __('Retro Map', 'address-autocomplete-for-woocommerce'), 'image' => '3.png' ),
				'4' => array( 'label' => __('Dark Map', 'address-autocomplete-for-woocommerce'), 'image' => '4.png' ),
				'5' => array( 'label' => __('Night Map', 'address-autocomplete-for-woocommerce'), 'image' => '5.png' ),
				'6' => array( 'label' => __('Aubergine Map', 'address-autocomplete-for-woocommerce'), 'image' => '6.png' ),
				'7' => array( 'label' => __('Basic Map', 'address-autocomplete-for-woocommerce'), 'image' => '7.png' ),
				'wcAddressAutocompleteUrl' => WC_ADDRESS_AUTOCOMPLETE_URL,
			));
		}
		wp_register_style( 'wcac-admin-style', WC_ADDRESS_AUTOCOMPLETE_URL . 'assets/Admin/css/admin.css', false, SHIPPING_WORKSHOP_VERSION );
	}

	/**
	 * Register style & scripts for Tier Pricing
	 *
	 * @since 1.0
	 */
	public static function front_enqueue_scripts() {

		wp_register_style( 'wcac-front-style', WC_ADDRESS_AUTOCOMPLETE_URL . 'assets/Public/css/front.css', false, SHIPPING_WORKSHOP_VERSION );
	}

	/**
	 * Instance Method to initiate class.
	 *
	 * @since 1.0
	 */
	public function woo_hpos_incompatibility() {
		if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
			\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
			\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'cart_checkout_blocks', __FILE__, true );
		}
	}
	public static function Instance() {
		if ( null === self::$_instance ) {
			self::$_instance = new WC_Address_Autocomplete();
		}

		return self::$_instance;
	}
}

WC_Address_Autocomplete::Instance();
